package SPVM::Go::Error::IOTimeout;



1;

=head1 Name

SPVM::Go::Error::IOTimeout - Short Description

=head1 Description

The Go::Error::IOTimeout class of L<SPVM> has methods to do someting.

=head1 Usage

  use Go::Error::IOTimeout;

=head1 Fields



=head1 Class Methods



=head1 Instance Methods




=head1 Repository



=head1 Author

Yuki Kimoto C<kimoto.yuki@gmail.com>

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

