package SPVM::Go::Schedule::Task;



1;

=head1 Name

SPVM::Go::Schedule::Task - Short Description

=head1 Description

Go::Schedule::Task class of L<SPVM> has methods to schedule goroutnies.

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

